From 54490bf61368a374d953928033c5e7b52605d14f Mon Sep 17 00:00:00 2001
From: Chris Lamb <lamby@debian.org>
Date: Fri, 24 Jul 2009 19:58:21 +0200
Subject: [PATCH 5/7] Use cdrom-detect/cdrom_fs when remounting the CD to ensure that we do so using the same filesystem. Patch by Colin Watson, merged back from Ubuntu.

---
 packages/apt-setup/debian/changelog   |    6 ++++++
 packages/apt-setup/generators/40cdrom |    6 +++++-
 packages/apt-setup/load-install-cd    |    6 +++++-
 3 files changed, 16 insertions(+), 2 deletions(-)

diff --git a/packages/apt-setup/debian/changelog b/packages/apt-setup/debian/changelog
index f2de784..0117000 100644
--- a/packages/apt-setup/debian/changelog
+++ b/packages/apt-setup/debian/changelog
@@ -1,7 +1,13 @@
 apt-setup (1:0.43) UNRELEASED; urgency=low
 
+  [ Colin Watson ]
   * Upgrade to debhelper v7.
 
+  [ Chris Lamb ]
+  * Use cdrom-detect/cdrom_fs when remounting the CD to ensure that we do so
+    using the same filesystem. Patch by Colin Watson, merged back from Ubuntu.
+    Requires cdrom-detect >= 1.32.
+
  -- Colin Watson <cjwatson@debian.org>  Thu, 13 Aug 2009 14:00:28 +0100
 
 apt-setup (1:0.42) unstable; urgency=low
diff --git a/packages/apt-setup/generators/40cdrom b/packages/apt-setup/generators/40cdrom
index a274d1f..09bba76 100755
--- a/packages/apt-setup/generators/40cdrom
+++ b/packages/apt-setup/generators/40cdrom
@@ -11,8 +11,12 @@ fi
 
 remount_cd() {
 	if [ "$ROOT" ] && [ ! -d /hd-media ]; then
+		fs=iso9660
+		if db_get cdrom-detect/cdrom_fs && [ "$RET" ]; then
+			fs="$RET"
+		fi
 		db_get cdrom-detect/cdrom_device
-		$logoutput mount -t iso9660 -o ro,exec $RET /cdrom || true
+		$logoutput mount -t "$fs" -o ro,exec $RET /cdrom || true
 	fi
 }
 
diff --git a/packages/apt-setup/load-install-cd b/packages/apt-setup/load-install-cd
index f3c8fac..ccf9bb5 100755
--- a/packages/apt-setup/load-install-cd
+++ b/packages/apt-setup/load-install-cd
@@ -29,5 +29,9 @@ while ! check_id; do
 	db_go || exit 10
 done
 
+fs=iso9660
+if db_get cdrom-detect/cdrom_fs && [ "$RET" ]; then
+	fs="$RET"
+fi
 db_get cdrom-detect/cdrom_device
-$logoutput mount -t iso9660 -o ro,exec $RET /cdrom
+$logoutput mount -t "$fs" -o ro,exec $RET /cdrom
-- 
1.6.3.3

